src/Network/Client.hh
changeset 381 9b35bc329d23
parent 332 78657bf06302
child 400 d64bf28c4340
--- a/src/Network/Client.hh	Tue Dec 16 23:21:26 2008 +0000
+++ b/src/Network/Client.hh	Wed Dec 17 00:40:22 2008 +0000
@@ -99,13 +99,13 @@
 
     public:
         /**
          * Create a NetworkClient with the given GameState, connecting a server on the given NetworkAddress
          *
          * @param engine the Engine we're running as
          * @param state the GameState to use
          * @param connect_to the address to connect to
          */
-        NetworkClient (Engine &engine, GameState &state, const NetworkAddress &connect_to);
+        NetworkClient (Engine &engine, GameState &state, const NetworkEndpoint &connect_to);
     
     protected:
         /**
@@ -99,13 +99,13 @@
     public:
         /**
-         * Create a NetworkClient with the given GameState, connecting a server on the given NetworkAddress
+         * Create a NetworkClient with the given GameState, connecting a server on the given NetworkEndpoint
          *
          * @param engine the Engine we're running as